# pynter
Tools for atomistic calculations, up to now has interface only to VASP. Uses pymatgen package (https://pymatgen.org).

Run setup.py to configure the file with the preferred default options for HPC job submissions and database.
Check out the notebook in the tutorials folder to get started.
